# UTF-8 encoded French language file for use with Oddmuse
#
# Copyright (c) 2003, 2005  Pierre Gaston
# Copyright (c) 2004, 2005  Christophe Ducamp
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.296.
#
$ModulesDescription .= '<p>$Id: french-utf8.pl,v 1.8 2005/07/04 09:24:27 as Exp $</p>';

%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Accès interdit&nbsp;: votre serveur, adresse IP ou nom d'utilisateur a été bloqué.
Could not create %s
Création impossible de %s
Invalid UserName %s: not saved.
Nom d'utilisateur non valide %s&nbsp;: non sauvegardé.
UserName must be 50 characters or less: not saved
Le nom d'utilisateur ne doit pas dépasser 50 caractères : non sauvegardé
This page contains an uploaded file:
Cette page contient un fichier téléversé :
XML::RSS is not available on this system.
XML::RSS n'est pas disponible sur ce système.
diff
diff
history
historique
%s returned no data, or LWP::UserAgent is not available.
 n'a pas retournée de données, ou LWP::UserAgent n'est pas disponible.
RSS parsing failed for %s
L'analyse du RSS de %s a échouée 
No items found in %s.
Pas d'objet dans %s.
 . . . . 
 . . . . 
Click to edit this page
Cliquez pour éditer cette page
image
image
download
télécharger
CGI Internal error: %s
Erreur Interne CGI : %s
Invalid action parameter %s
Parmètre d'action invalide %s
Invalid URL.
URL non valide
Page name is missing
Le nom de la page est manquant
Page name is too long: %s
Le nom de la page est trop long&nbsp;: %s
Invalid Page %s
Page non valide %s
Invalid Page %s (must not end with .db)
Page non valide %s (elle ne doit pas se terminer par .db)
Invalid Page %s (must not end with .lck)
Page non valide %s (elle ne doit pas se terminer par .lck)
Page name may not contain space characters: %s
Le nom de la page ne peut pas contenir d'espaces&nbsp;: %s
Preview:
Prévisualisation&nbsp;:
Preview only, not yet saved
Prévisualisation seulement, pas encore sauvegardée
Please go on to %s.
SVP aller a %s.
Could not open %s log file
Impossible d'ouvrir le fichier de log %
Error was
L'erreur était
Note: This error is normal if no changes have been made.
Remarque&nbsp;: Cette erreur est normale si aucune modification n'a été effectuée.
Could not open old %s log file
Impossible d'ouvrir l'ancien fichier de log %
No updates since %s
Aucune mise à jour depuis le %s
Updates since %s
Mises à hour depuis %s
Updates in the last %s days
Mises à jour durant les derniers %s jours
Updates in the last %s day
Mises à jour durant le dernier %s jour
for %s only
pour %s seulement
List latest change per page only
Lister seulement les dernières modifications par page
List all changes
Lister toutes les modifications
List only major changes
Lister seulement les modifications majeures
Include minor changes
Inclure les modifications mineures
%s days
%s jours
List later changes
Lister les modifications les plus récentes
Filters
Filtres
Username:
Nom d'utilisateur&nbsp;:
Host:
Hôte&nbsp;:
Language:
Langue&nbsp;:
Go!
Allez-y !
(minor)
(mineur)
rollback
retour en arrière
new
nouveau
from %s
depuis %s
History of %s
Historique de %s
Compare
Comparaison
Revision %s
Version %s
by
par
Rolling back changes
Retour en arrière en cours
Missing target for rollback.
Cible manquante pour le retour en arrière.
Target for rollback is too far back.
La cible du retour en arrière est trop ancienne.
Rollback to %s
Retour à %s
%s rolled back
Retour en arrière pour %s
Index of all pages
Index de toutes les pages
Wiki Version
Affiche la version du wiki
Unlock Wiki
Supression du verrou
Recent Visitors
Derniers Visiteurs
Password
Mot de passe
Run maintenance
Lancer la maintenance
Unlock site
Déverouiller le site
Lock site
Verouiller le site
Unlock %s
Déverrouiller %s
Lock %s
Verrouiller %s
Administration
Administration
Actions:
Actions:
Important pages:
Pages importantes :
To mark a page for deletion, put <strong>%s</strong> on the first line.
Pour marquer une page devant être supprimer, ajoutez <strong>%s</strong> à la première ligne
[Home]
[Accueil]
redirected from %s
redirigée à partir de %s
Click to search for references to this page
Cliquer pour chercher des références vers cette page
Cookie: 
Cookie&nbsp;: 
Warning
Attention
Database is stored in temporary directory %s
La base de données est stockée dans le répertoire temporaire %s
%s seconds
%s secondes
The same page on other sites:
La même page sur d'autres sites :
EditNearLinks
EditerLiensDeProximité
Last edited
Dernière modification
Edited
Modifié
by %s
par %s
(diff)
(diff)
Edit revision %s of this page
Modifier la version %s de cette page
Edit this page
Modifier cette page
e
e
This page is read-only
Cette page est en lecture seule
View other revisions
Voir les autres versions
View current revision
Voir la version actuelle
View all changes
Voir toutes les modifications
Homepage URL:
Adresse(URL) du site perso
s
s
Save
Sauvegarder
Preview
Prévisualisation
Search:
Rechercher&nbsp;:
f
f
Replace:
Remplacer&nbsp;:
Validate HTML
Validation du HTML
Validate CSS
Validation des CSS
Difference (from revision %1 to %2)
Différence (de la révision %1 à %2)
revision %s
version %s
current revision
version actuelle
Difference (from prior %s revision)
Différences (à partir des dernières versions %s)
major
majeure
minor
mineure
No diff available.
Pas de diff disponible.
Old revision:
Ancienne version:
Changed:
Modifiée&nbsp;:
Removed:
Suprimée&nbsp;:
Added:
Ajoutée&nbsp;:
to
à
Revision %s not available
La version %s n'est pas disponible
showing current revision instead
présentation à la place de la version en cours.
Showing revision %s
Présentation de la version %s
Cannot save a nameless page.
Impossible de sauvegarder une page sans nom.
Cannot save a page without revision.
Impossible de sauvegarder une page sans version.
Cannot open %s
Ne peut pas ouvrir %s
Cannot write %s
Ne peut pas écrire %s
Cannot create %s
Impossible de créer %s
Could not get %s lock
Ne peut obtenir un verrouillage %s
This operation may take several seconds...
Cette opération peut prendre quelques secondes...
Forced unlock of %s lock.
Supression forcée du verrou %s.
No unlock required.
La suppression du verrou n'est pas nécessaire.
%s hours ago
il y a %s heures
1 hour ago
il y a une heure
%s minutes ago
il y a %s minutes
1 minute ago
il y a une minute
%s seconds ago
il y a %s secondes
1 second ago
il y a 1 seconde
just now
à l'instant
Editing Denied
Modification interdite
Editing not allowed: user, ip, or network is blocked.
Modification interdite&nbsp;: l'utilisateur, l'adresse ip, ou le reseau est bloqué.
Contact the wiki administrator for more information.
Contactez l'administrateur du wiki pour plus d'information.
The rule %s matched for you.
La règle %s a fonctionné pour vous.
See %s for more information.
Voir %s pour plus d'information.
Editing not allowed: %s is read-only.
Modification interdite&nbsp;: %s est en lecture seule.
Only administrators can upload files.
Seuls les administrateurs peuvent téléverser des fichiers.
Editing revision %s of
Modification de la version %s de
Editing %s
Modification de %s
Editing old revision %s.
Modification de l'ancienne version %s.
Saving this page will replace the latest revision with this text.
Sauvegarder cette page remplacera la dernière version par ce texte.
Summary:
Résumé&nbsp;:
This change is a minor edit.
Cette modification est mineure.
Replace this file with text.
Remplacer ce fichier par un texte.
Replace this text with a file.
Remplacer ce texte par un fichier.
File to upload: 
Fichier à téléverser&nbsp;: 
Files of type %s are not allowed.
Les fichiers de type %s ne sont pas autorisés.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Votre mot de passe est conservé dans un cookie, si cette fonctionnalité est activée dans votre navigateur. Les cookies peuvent être perdus si vous vous reconnectez à partir d'une autre machine, d'un autre compte ou en utilisant un autre logiciel.
You are currently an administrator on this site.
Vous êtes actuellement administrateur de ce site.
You are currently an editor on this site.
Vous êtes actuellement éditeur de ce site.
You are a normal user on this site.
Vous êtes un utilisateur normal sur ce site.
Your password does not match any of the  administrator or editor passwords.
Vote mot de passe ne corespond à aucun de ceux des mots de passe administrateurs ou éditeurs.
Password:
Mot de passe&nbsp;:
This site does not use admin or editor passwords.
Ce site n'utilise pas de mot de passe pour les administrateurs ou les éditeurs.
This operation is restricted to site editors only...
Cette opération est réservée aux éditeurs du site seulement...
This operation is restricted to administrators only...
Cette opération est réservée aux administrateurs seulement...
Rule "%1" matched "%2" on this page.
"%2" correspond à la règle "%1" sur cette page.
Without normal pages
Sans pages normales 
Include normal pages
Comprend les pages normales
Without permanent anchors
Sans ancre permanente
Include permanent anchors
Inclure les ancres permanentes
Without near pages
Sans les pages à proximité
Include near pages
Inclure les pages à proximité
(for %s)
(pour %s)
%s pages found.
%s pages trouvées.
Replaced: %s
Remplacé&nbsp;: %s
Search for: %s
Rechercher&nbsp;: %s
View changes for these pages
Voir les modifications pour ces pages
Search sites on the %s as well
Rechercher aussi les sites présents sur %s 
and
et
or
ou
Fetching results from %s:
Récupération des résultats à partir de %s en cours
Near pages:
Pages à proximité :
last updated
dernière mise à jour
Complete Content
Contenu Complet
The main page is %s.
La page principale est %s.
Comments on this page
Commentaires sur cette page
Editing not allowed for %s.
Edition non autorisée pour %s.
SampleUndefinedPage
ExempleDePageNonDéfinie
%s cannot be defined.
%s ne peut être défini.
Sample_Undefined_Page
Exemple_De_Page_NonDéfinie
[[%s]] cannot be defined.
[[%s]] ne peut être défini.
Only an administrator can create %s.
Seul un administrateur peut créer %s.
Transfer Error: %s
Erreur de Transfert&nbsp;: %s
Browser reports no file info.
Le navigateur signale pas d'information sur le fichier.
Browser reports no file type.
Le navigateur signale pas de format de fichier.
Edit Denied
Modification interdite
The page contains banned text.
Cette page contient un texte interdit.
This page was changed by somebody else %s.
Cette page a été modifiée par quelqu'un d'autre %s.
The changes conflict.  Please check the page again.
Conflit sur les modifications. SVP vérifiez la page à nouveau.
Please check whether you overwrote those changes.
SVP vérifiez si vous souhaitez écrase ces modifications.
Anonymous
Anonyme
Cannot delete the index file %s.
Impossible de supprimer le fichier index  %s.
Please check the directory permissions.
Veuillez vérifier les permissions des répertoires.
Your changes were not saved.
Vos modifications n'ont pas été sauvegardées
Could not get a lock to merge!
Pas pu obtenir de verrouillage pour la fusion !
you
vous
ancestor
ancêtre
other
autre
Run Maintenance
Lancer la maintenance
Maintenance not done.
Maintenance non effectuée.
(Maintenance can only be done once every 12 hours.)
(La maintenance ne peut être effectuée qu'une fois toutes les 12 heures.)
Remove the "maintain" file or wait.
Enlevez le fichier "maintain" ou patientez.
Main lock obtained.
Verrou principal obtenu.
Expiring keep files and deleting pages marked for deletion
Expiration des fichiers de cache et suppression des pages marquées pour la suppression
not deleted: 
non supprimée :
deleted
supprimé
Moving part of the %s log file.
Deplace une partie du fichier de log %s.
Moving %s log entries.
Déplace %s entrées du log.
Getting page index file for %s.
Récupération du fichier d'index de %s.
Main lock released.
Verrou principal rendu.
Set or Remove global edit lock
Positionne ou Retire le verrou global d'édition
Edit lock created.
Verrou d'édition créé.
Edit lock removed.
Verrou d'édition enlevé.
Set or Remove page edit lock
Positionne ou enlève le verrou d'édition de la page
Missing page id to lock/unlock...
Id de page manquant pour verrouiller/déverrouiller...
Lock for %s created.
Verrou pour %s créé.
Lock for %s removed.
Verrou pour %s enlevé.
Displaying Wiki Version
Affichage de la version du Wiki
Show dependencies
Afficher les dépendances
Inter links:
InterLiens :
Near links:
Liens de proximité :
Show parsed link data
Affcher les données de liens analysées
Too many connections by %s
Trop de connexions par %s
Please do not fetch more than %1 pages in %2 seconds.
Veuillez ne pas télécharger plus de %1 pages toutes les %2 secondes
Check whether the web server can create the directory %s and whether it can create files in it.
Verifiez si le serveur web peut créer le répertoire %s et s'il peut y créer des fichiers
anchor first defined here: %s
première ancre définie ici&nbsp;: %s
Click to search for references to this permanent anchor
Cliquer pour chercher des références vers cette ancre permanente
the page %s also exists
la page %s existe aussi 
Deleting %s
supression de %s
Deleted %s
%s supprimée
Renaming %1 to %2.
Change  %1 en %2.
The page %s does not exist
La page %s n'existe pas
The page %s already exists
La page %s existe déjà
Cannot rename %1 to %2
Impossible de renommer %1 %2
Renamed to %s
Renommé  %s
Renamed from %s
Nom précédent %s
Renamed %1 to %2.
%1 a été renommée en %2.
Immediately delete %s
Supprimer immédiatement %s
Rename %s to:
Renommer %s en :
Cannot highlight the language %s.
Impossible de surligner la langue %s.
Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
cal(1), Date::Calc(3) ou Date::Pcalc(3) manque pour pouvoir créer le calendrier.
The match parameter is missing.
Le paramètre de correspondance est manquant
Page Collection for %s
Liste des pages pour %s
Previous
Précédent
Next
Suivant
Calendar %s
Calendrier %s
Clustermap
Carte du Faisceau
Pages without a Cluster
Pages sans un Faisceau
Comments on 
Commentaires sur
Comment on 
Commentaire sur
Compilation for %s
Compilation pour %s
Compilation tag is missing a regular expression.
Il manque une expression régulière pour l'etiquette de la compilation
Despamming pages
Suprresion des textes indésirables sur les pages.
Cannot find revision %s.
Impossible de trouver la version %s.
Revert to revision %1: %2
Retour à la version %1 : %2
Marked as %s.
Marqué comme %s.
Cannot find unspammed revision.
Impossible de trouver une version sans texte indésirable.
Footnotes:
Note de pied de pages :
Could not find %1.html template in %2
Impossible de trouver le modèle %1.html dans %2
image: %s
image : %s
Index
Index
Languages:
Langues :
Show!
Voir !
Define
Définir
Full Link List
Liste Complète des Liens
Template without parameters
Gabarit sans paramètres
The template %s is either empty or does not exist.
Le gabarit %s est soit vide soit n'existe pas.
Register for %s
Enregistrer pour %s
Please choose a username of the form "FirstLast" using your real name.
SVP choisissez un nom d'utilisateur sous la forme "PrénomNom" en utilisant votre vrai nom.
The passwords do not match.
Les mots de passe ne correspondent pas.
The password must be at least %s characters.
Le mot de passe doit être au moins de %s caractères.
That email address is invalid.
Cette adresse e-mail n'est pas valide.
The username %s has already been registered.
Le nom d'utilisateur %s a déjà été enregistré.
Your registration for %s has been submitted.
Votre enregistrement pour %s a été soumis.
  Please allow time for the webmaster to approve your request.
  SVP, donnez un peu de temps au webmestre pour valider votre demande.
An account was created for %s.
Un compte a été créé pour %s
Login to %s
Se connecter sur %s

Username and/or password are incorrect.
Le nom d'utilisateur et/ou le mot de passe sont incorrects.
Logged in as %s.
Connecté comme %s.
Logout of %s
Déconnexion de %s
Logout of %s?
Se déconnecter de %s?
Logged out of %s
Déconnecté de %s
You are now logged out.
Vous êtes maintenant déconnecté.
Register a new account
Enregistrer un nouveau compte.
Login
Se connecter
Logout
Se déconnecter
Clearing Cache
Nettoyage du cache.
Done.
effectué.
Generating Link Database
Création de la base de donnée de liens
The 404 handler extension requires the link data extension (links.pl).
l'extension "404 handler" nécessite une base de donnée de liens (links.pl).
LocalMap
CarteLocale
No page id for action localmap
Aune page id pour actionner la carte locale
Requested page %s does not exist
La page demandée %s n'existe pas
Local Map for %s
CarteLocale pour %s
view
voir
Orphan List
Liste des pages orphelines
Trail: 
Trace :
None
Aucune
Type
Type
Permalink to "%s"
Lien permanent vers
Portrait
Portrait
You did not answer correctly.
Vous n'avez pas répondu correctement
All Referrers
Tous les Introducteurs
Referrers
Introducteurs
Rebuild index for searching
Reconstruire l'index pour la recherche
Rebuilding Index
Reconstruction de l'Index
Search::FreeText is not available on this system.
Chercher::Le TexteLibre n'est pas disponible sur ce système.
Rebuilding index not done.
Reconstruction index non effectuée.
(Rebuilding the index can only be done once every 12 hours.)
(La reconstruction de l'index ne peut être faite qu'une fois toutes les 12 heures.)
Search term missing.
Terme de la recherche manquant
Result pages: 
Pages de résultats :
(%s results)
(%s résultats)
Slideshow:%s
Diaporama : %s
Static Copy
Copie Statique
Back to %s
Retour à %s
Tag
Tag
Alternatively, use one of the following templates:
Alternativement, utilisez un des modèles suivants :
Thread: %s
Fil: %s
ID parameter is missing.
Le paramètre ID est manquant. 
Thread %s does not exist.
Le fil %s n'existe pas.
Page %s does not contain a thread.
La page %s ne contient pas de fil.
Add
Ajoutez
URL parameter is missing.
Le paramètre URL est manquant.
Add to %s thread
Ajoutez %s au fil
Below:
En-dessous :
URL:
URL :
Name:
Nom :
Failed to remove %s
Impossible de supprimer %s
Contents
Contenus :
This page is a translation of %s. 
Cette page est une traduction de %s.
The translation is up to date.
La traduction est à jour
The translation is outdated.
La traduction n'est pas à jour.
The page does not exist.
La page n'existe pas.
http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.fr/exec/obidos/ISBN=%s
alternate
Alternative
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
Recherche
Blog
Blog
END_OF_TRANSLATION
